{config, lib, pkgs, ...}: 

{
  home-manager.users.hexchen = {
    programs.direnv = {
      enable = true;
      enableFishIntegration = true;
      enableNixDirenvIntegration = true;
    };
    programs.fish = {
      enable = true;
      shellAliases = {
        icat = "${pkgs.kitty}/bin/kitty +kitten icat";
      };
      plugins = [
        {
          name = "bass";
          src = pkgs.fetchFromGitHub {
            owner = "edc";
            repo = "bass";
            rev = "d63054b24c2f63aaa3a08fb9ec9d0da4c70ab922";
            sha256 = "0pwci5xxm8308nrb52s5nyxijk0svar8nqrdfvkk2y34z1cg319b";
          };
        }
      ];
    };
    programs.vim = {
      enable = true;
      extraConfig = ''
        set viminfo='20,<1000
        set mouse=a
      ''; /*
        set tabstop=2
        set shiftwidth=2
        set expandtab
      '';*/
    };

    programs.git = {
      enable = true;
      userName = "hexchen";
      userEmail = "hexchen@lilwit.ch";
    };

    programs.bat.enable = true;
    programs.jq.enable = true;
    programs.tmux.enable = true;
    programs.ssh = {
      enable = true;
      controlMaster = "auto";
      controlPersist = "10m";
      hashKnownHosts = true;
      matchBlocks = let
        hexchen = {
          forwardAgent = true;
          extraOptions = {
            RemoteForward = "/run/user/1000/gnupg/S.gpg-agent /run/user/1000/gnupg/S.gpg-agent.extra";
          };
          port = 62954;
        };
      in {
	"*.chaoswit.ch" = hexchen;
	"*.copyonwit.ch" = hexchen;
	"*.lilwit.ch" = hexchen;
	"*.hxchn.de" = hexchen;
        "*.hacc.space" = hexchen;
      };
    };
  };

}
