{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-config.nix
      ../../common
      ../../desktop
      ../../desktop/streaming.nix
      ../../desktop/sway.nix
      ../../desktop/gnome.nix
    ];

  boot.loader.grub ={
    enable = true;
    version = 2;
    efiSupport = true;
    device = "nodev";
  };
  boot.loader.efi = {
    canTouchEfiVariables = true;
    efiSysMountPoint = "/boot";
  };

# hardware.decklink.enable = true;

  networking.hostName = "nixda"; # Define your hostname.

  boot.kernelModules = [ "blackmagic" "blackmagic-io" "snd_blackmagic-io" ];
  boot.extraModulePackages = [ config.boot.kernelPackages.decklink ];
  systemd.services."DecklinkVideoHelper" = {
    after = [ "syslog.target" "local-fs.target" ];
    wantedBy = [ "multi-user.target" ];
    serviceConfig.ExecStart = "${pkgs.blackmagicDesktopVideo}/bin/DesktopVideoHelper -n";
  };

  environment.systemPackages = with pkgs; [ blackmagicDesktopVideo makemkv ];

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "20.09"; # Did you read the comment?

}
